@@ -79,7 +79,7 @@ func NewSkaffoldCommand(out, errOut io.Writer) *cobra.Command {
 
 			opts.Command = cmd.Use
 			instrumentation.SetCommand(cmd.Use)
-			out := output.SetupColors(out, defaultColor, forceColors)
+			out := output.GetWriter(out, defaultColor, forceColors)
 			if timestamps {
 				l := logrus.New()
 				l.SetOutput(out)
@@ -284,14 +284,14 @@ func isHouseKeepingMessagesAllowed(cmd *cobra.Command) bool {
 	if cmd.Annotations == nil {
 		return false
 	}
-	return cmd.Annotations[HouseKeepingMessagesAllowedAnnotation] == "true"
+	return cmd.Annotations[HouseKeepingMessagesAllowedAnnotation] == fmt.Sprintf("%t", true)
 }
 
 func allowHouseKeepingMessages(cmd *cobra.Command) {
 	if cmd.Annotations == nil {
 		cmd.Annotations = make(map[string]string)
 	}
-	cmd.Annotations[HouseKeepingMessagesAllowedAnnotation] = "true"
+	cmd.Annotations[HouseKeepingMessagesAllowedAnnotation] = fmt.Sprintf("%t", true)
 }
 
 func preReleaseVersion(s string) bool {
