@@ -41,14 +41,12 @@ func main() {
 			// As we allow some color setup using CLI flags for the main run, we can't run SetupColors()
 			// for the entire skaffold run here. It's possible SetupColors() was never called, so call it again
 			// before we print an error to get the right coloring.
-			errOut := output.SetupColors(os.Stderr, output.DefaultColorCode, false)
+			errOut := output.GetWriter(os.Stderr, output.DefaultColorCode, false)
 			output.Red.Fprintln(errOut, err)
 			code = exitCode(err)
 		}
 	}
-	if err := instrumentation.ExportMetrics(code); err != nil {
-		logrus.Debugf("error exporting metrics %v", err)
-	}
+	instrumentation.ShutdownAndFlush(context.Background(), code)
 	os.Exit(code)
 }
 
