@@ -156,7 +156,7 @@ func TestJdwpTransformerApply(t *testing.T) {
 	}
 	for _, test := range tests {
 		testutil.Run(t, test.description, func(t *testutil.T) {
-			config, image, err := jdwpTransformer{}.Apply(&test.containerSpec, test.configuration, identity)
+			config, image, err := jdwpTransformer{}.Apply(&test.containerSpec, test.configuration, identity, nil)
 
 			// Apply never fails since there's always the option to set JAVA_TOOL_OPTIONS
 			t.CheckNil(err)
