@@ -21,7 +21,6 @@ import (
 	"encoding/json"
 	"fmt"
 	"os"
-	"strconv"
 	"sync"
 
 	//nolint:golint,staticcheck
@@ -31,7 +30,6 @@ import (
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/constants"
 	sErrors "github.com/GoogleContainerTools/skaffold/pkg/skaffold/errors"
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/event"
 	proto "github.com/GoogleContainerTools/skaffold/proto/v2"
 )
 
@@ -70,7 +68,9 @@ type eventHandler struct {
 	logLock             sync.Mutex
 	applicationLogs     []proto.Event
 	applicationLogsLock sync.Mutex
-	cfg                 event.Config
+	skaffoldLogs        []proto.Event
+	skaffoldLogsLock    sync.Mutex
+	cfg                 Config
 
 	iteration               int
 	state                   proto.State
@@ -78,6 +78,7 @@ type eventHandler struct {
 	eventChan               chan *proto.Event
 	eventListeners          []*listener
 	applicationLogListeners []*listener
+	skaffoldLogListeners    []*listener
 }
 
 type listener struct {
@@ -103,6 +104,10 @@ func ForEachApplicationLog(callback func(*proto.Event) error) error {
 	return handler.forEachApplicationLog(callback)
 }
 
+func ForEachSkaffoldLog(callback func(*proto.Event) error) error {
+	return handler.forEachSkaffoldLog(callback)
+}
+
 func Handle(event *proto.Event) error {
 	if event != nil {
 		handler.handle(event)
@@ -148,6 +153,10 @@ func (ev *eventHandler) logApplicationLog(event *proto.Event) {
 	ev.log(event, &ev.applicationLogListeners, &ev.applicationLogs, &ev.applicationLogsLock)
 }
 
+func (ev *eventHandler) logSkaffoldLog(event *proto.Event) {
+	ev.log(event, &ev.skaffoldLogListeners, &ev.skaffoldLogs, &ev.skaffoldLogsLock)
+}
+
 func (ev *eventHandler) forEach(listeners *[]*listener, log *[]proto.Event, lock sync.Locker, callback func(*proto.Event) error) error {
 	listener := &listener{
 		callback: callback,
@@ -180,7 +189,11 @@ func (ev *eventHandler) forEachApplicationLog(callback func(*proto.Event) error)
 	return ev.forEach(&ev.applicationLogListeners, &ev.applicationLogs, &ev.applicationLogsLock, callback)
 }
 
-func emptyState(cfg event.Config) proto.State {
+func (ev *eventHandler) forEachSkaffoldLog(callback func(*proto.Event) error) error {
+	return ev.forEach(&ev.skaffoldLogListeners, &ev.skaffoldLogs, &ev.skaffoldLogsLock, callback)
+}
+
+func emptyState(cfg Config) proto.State {
 	builds := map[string]string{}
 	for _, p := range cfg.GetPipelines() {
 		for _, a := range p.Build.Artifacts {
@@ -273,7 +286,7 @@ func emptyStatusCheckState() *proto.StatusCheckState {
 }
 
 // InitializeState instantiates the global state of the skaffold runner, as well as the event log.
-func InitializeState(cfg event.Config) {
+func InitializeState(cfg Config) {
 	handler.cfg = cfg
 	handler.setState(emptyState(cfg))
 }
@@ -287,20 +300,21 @@ func AutoTriggerDiff(phase constants.Phase, val bool) (bool, error) {
 	case constants.Deploy:
 		return val != handler.getState().DeployState.AutoTrigger, nil
 	default:
-		return false, fmt.Errorf("unknown phase %v not found in handler state", phase)
+		return false, fmt.Errorf("unknown Phase %v not found in handler state", phase)
 	}
 }
 
-func TaskInProgress(task constants.Phase) {
+func TaskInProgress(task constants.Phase, description string) {
 	if task == constants.DevLoop {
 		handler.iteration++
 	}
 
 	handler.handleTaskEvent(&proto.TaskEvent{
-		Id:        fmt.Sprintf("%s-%d", task, handler.iteration),
-		Task:      string(task),
-		Iteration: int32(handler.iteration),
-		Status:    InProgress,
+		Id:          fmt.Sprintf("%s-%d", task, handler.iteration),
+		Task:        string(task),
+		Description: description,
+		Iteration:   int32(handler.iteration),
+		Status:      InProgress,
 	})
 }
 
@@ -324,34 +338,6 @@ func TaskSucceeded(task constants.Phase) {
 	})
 }
 
-func BuildInProgress(id int, artifact string) {
-	handler.handleBuildSubtaskEvent(&proto.BuildSubtaskEvent{
-		Id:       strconv.Itoa(id),
-		TaskId:   fmt.Sprintf("%s-%d", constants.Build, handler.iteration),
-		Artifact: artifact,
-		Status:   InProgress,
-	})
-}
-
-func BuildFailed(id int, artifact string, err error) {
-	handler.handleBuildSubtaskEvent(&proto.BuildSubtaskEvent{
-		Id:            strconv.Itoa(id),
-		TaskId:        fmt.Sprintf("%s-%d", constants.Build, handler.iteration),
-		Artifact:      artifact,
-		Status:        Failed,
-		ActionableErr: sErrors.ActionableErrV2(handler.cfg, constants.Build, err),
-	})
-}
-
-func BuildSucceeded(id int, artifact string) {
-	handler.handleBuildSubtaskEvent(&proto.BuildSubtaskEvent{
-		Id:       strconv.Itoa(id),
-		TaskId:   fmt.Sprintf("%s-%d", constants.Build, handler.iteration),
-		Artifact: artifact,
-		Status:   Succeeded,
-	})
-}
-
 func (ev *eventHandler) setState(state proto.State) {
 	ev.stateLock.Lock()
 	ev.state = state
@@ -378,24 +364,21 @@ func (ev *eventHandler) handleTaskEvent(e *proto.TaskEvent) {
 	})
 }
 
-func (ev *eventHandler) handleBuildSubtaskEvent(e *proto.BuildSubtaskEvent) {
-	ev.handle(&proto.Event{
-		EventType: &proto.Event_BuildSubtaskEvent{
-			BuildSubtaskEvent: e,
-		},
-	})
-}
-
 func (ev *eventHandler) handleExec(event *proto.Event) {
 	switch e := event.GetEventType().(type) {
 	case *proto.Event_ApplicationLogEvent:
 		ev.logApplicationLog(event)
 		return
+	case *proto.Event_SkaffoldLogEvent:
+		ev.logSkaffoldLog(event)
+		return
 	case *proto.Event_BuildSubtaskEvent:
 		be := e.BuildSubtaskEvent
-		ev.stateLock.Lock()
-		ev.state.BuildState.Artifacts[be.Artifact] = be.Status
-		ev.stateLock.Unlock()
+		if be.Step == Build {
+			ev.stateLock.Lock()
+			ev.state.BuildState.Artifacts[be.Artifact] = be.Status
+			ev.stateLock.Unlock()
+		}
 	case *proto.Event_TestEvent:
 		te := e.TestEvent
 		ev.stateLock.Lock()
@@ -414,7 +397,7 @@ func (ev *eventHandler) handleExec(event *proto.Event) {
 	case *proto.Event_StatusCheckSubtaskEvent:
 		se := e.StatusCheckSubtaskEvent
 		ev.stateLock.Lock()
-		ev.state.StatusCheckState.Status = se.Status
+		ev.state.StatusCheckState.Resources[se.Resource] = se.Status
 		ev.stateLock.Unlock()
 	case *proto.Event_FileSyncEvent:
 		fse := e.FileSyncEvent
