@@ -70,7 +70,8 @@ func (r *Builder) GetBuilds() []graph.Artifact {
 
 // Build builds a list of artifacts.
 func (r *Builder) Build(ctx context.Context, out io.Writer, artifacts []*latestV1.Artifact) ([]graph.Artifact, error) {
-	eventV2.TaskInProgress(constants.Build)
+	eventV2.TaskInProgress(constants.Build, "Build Containers")
+	eventV2.AssignArtifactIDs(artifacts)
 
 	// Use tags directly from the Kubernetes manifests.
 	if r.runCtx.DigestSource() == NoneDigestSource {
