@@ -31,6 +31,7 @@ import (
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/event"
 	eventV2 "github.com/GoogleContainerTools/skaffold/pkg/skaffold/event/v2"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/graph"
+	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/instrumentation"
 	kubernetesclient "github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes/client"
 	kubectx "github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes/context"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/output"
@@ -40,8 +41,6 @@ import (
 
 // DeployAndLog deploys a list of already built artifacts and optionally show the logs.
 func (r *SkaffoldRunner) DeployAndLog(ctx context.Context, out io.Writer, artifacts []graph.Artifact) error {
-	eventV2.TaskInProgress(constants.Deploy)
-
 	// Update which images are logged.
 	r.AddTagsToPodSelector(artifacts)
 
@@ -52,7 +51,6 @@ func (r *SkaffoldRunner) DeployAndLog(ctx context.Context, out io.Writer, artifa
 	logger.SetSince(time.Now())
 	// First deploy
 	if err := r.Deploy(ctx, out, artifacts); err != nil {
-		eventV2.TaskFailed(constants.Deploy, err)
 		return err
 	}
 
@@ -65,7 +63,6 @@ func (r *SkaffoldRunner) DeployAndLog(ctx context.Context, out io.Writer, artifa
 
 	// Start printing the logs after deploy is finished
 	if err := logger.Start(ctx, r.runCtx.GetNamespaces()); err != nil {
-		eventV2.TaskFailed(constants.Deploy, err)
 		return fmt.Errorf("starting logger: %w", err)
 	}
 
@@ -74,7 +71,6 @@ func (r *SkaffoldRunner) DeployAndLog(ctx context.Context, out io.Writer, artifa
 		<-ctx.Done()
 	}
 
-	eventV2.TaskSucceeded(constants.Deploy)
 	return nil
 }
 
@@ -125,12 +121,16 @@ See https://skaffold.dev/docs/pipeline-stages/taggers/#how-tagging-works`)
 	}
 
 	event.DeployInProgress()
-	eventV2.TaskInProgress(constants.Deploy)
+	eventV2.TaskInProgress(constants.Deploy, "Deploy to cluster")
+	ctx, endTrace := instrumentation.StartTrace(ctx, "Deploy_Deploying")
+	defer endTrace()
+
 	namespaces, err := r.deployer.Deploy(ctx, deployOut, artifacts)
 	postDeployFn()
 	if err != nil {
 		event.DeployFailed(err)
 		eventV2.TaskFailed(constants.Deploy, err)
+		endTrace(instrumentation.TraceEndError(err))
 		return err
 	}
 
@@ -139,8 +139,10 @@ See https://skaffold.dev/docs/pipeline-stages/taggers/#how-tagging-works`)
 	statusCheckOut, postStatusCheckFn, err := deployutil.WithStatusCheckLogFile(time.Now().Format(deployutil.TimeFormat)+".log", out, r.runCtx.Muted())
 	defer postStatusCheckFn()
 	if err != nil {
+		endTrace(instrumentation.TraceEndError(err))
 		return err
 	}
+
 	event.DeployComplete()
 	eventV2.TaskSucceeded(constants.Deploy)
 	r.runCtx.UpdateNamespaces(namespaces)
@@ -210,7 +212,10 @@ func (r *SkaffoldRunner) performStatusCheck(ctx context.Context, out io.Writer)
 		return nil
 	}
 
-	eventV2.TaskInProgress(constants.StatusCheck)
+	eventV2.TaskInProgress(constants.StatusCheck, "")
+	ctx, endTrace := instrumentation.StartTrace(ctx, "performStatusCheck_WaitForDeploymentToStabilize")
+	defer endTrace()
+
 	start := time.Now()
 	output.Default.Fprintln(out, "Waiting for deployments to stabilize...")
 
