@@ -20,6 +20,7 @@ import (
 	"context"
 	"fmt"
 	"io"
+	"strconv"
 	"time"
 
 	"github.com/sirupsen/logrus"
@@ -31,7 +32,6 @@ import (
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/graph"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/instrumentation"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes/logger"
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes/portforward"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/output"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/runner"
 	latestV1 "github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest/v1"
@@ -47,7 +47,7 @@ var (
 	fileSyncSucceeded  = event.FileSyncSucceeded
 )
 
-func (r *SkaffoldRunner) doDev(ctx context.Context, out io.Writer, logger *logger.LogAggregator, forwarderManager portforward.Forwarder) error {
+func (r *SkaffoldRunner) doDev(ctx context.Context, out io.Writer, logger *logger.LogAggregator, watchers ...Watcher) error {
 	// never queue intents from user, even if they're not used
 	defer r.intents.Reset()
 
@@ -69,12 +69,19 @@ func (r *SkaffoldRunner) doDev(ctx context.Context, out io.Writer, logger *logge
 	// if any action is going to be performed, reset the monitor's changed component tracker for debouncing
 	defer r.monitor.Reset()
 	defer r.listener.LogWatchToUser(out)
+
 	event.DevLoopInProgress(r.devIteration)
-	eventV2.TaskInProgress(constants.DevLoop)
+	eventV2.InitializeState(r.runCtx)
+	eventV2.TaskInProgress(constants.DevLoop, "")
 	defer func() { r.devIteration++ }()
+	eventV2.LogMetaEvent()
+	ctx, endTrace := instrumentation.StartTrace(ctx, "doDev_DevLoopInProgress", map[string]string{
+		"devIteration": strconv.Itoa(r.devIteration),
+	})
 
 	meterUpdated := false
 	if needsSync {
+		childCtx, endTrace := instrumentation.StartTrace(ctx, "doDev_needsSync")
 		defer func() {
 			r.changeSet.ResetSync()
 			r.intents.ResetSync()
@@ -86,20 +93,24 @@ func (r *SkaffoldRunner) doDev(ctx context.Context, out io.Writer, logger *logge
 			output.Default.Fprintf(out, "Syncing %d files for %s\n", fileCount, s.Image)
 			fileSyncInProgress(fileCount, s.Image)
 
-			if err := r.syncer.Sync(ctx, s); err != nil {
+			if err := r.syncer.Sync(childCtx, s); err != nil {
 				logrus.Warnln("Skipping deploy due to sync error:", err)
 				fileSyncFailed(fileCount, s.Image, err)
 				event.DevLoopFailedInPhase(r.devIteration, constants.Sync, err)
 				eventV2.TaskFailed(constants.DevLoop, err)
+				endTrace(instrumentation.TraceEndError(err))
+
 				return nil
 			}
 
 			fileSyncSucceeded(fileCount, s.Image)
 		}
+		endTrace()
 	}
 
 	var bRes []graph.Artifact
 	if needsBuild {
+		childCtx, endTrace := instrumentation.StartTrace(ctx, "doDev_needsBuild")
 		event.ResetStateOnBuild()
 		defer func() {
 			r.changeSet.ResetBuild()
@@ -111,19 +122,22 @@ func (r *SkaffoldRunner) doDev(ctx context.Context, out io.Writer, logger *logge
 		}
 
 		var err error
-		bRes, err = r.Build(ctx, out, r.changeSet.NeedsRebuild())
+		bRes, err = r.Build(childCtx, out, r.changeSet.NeedsRebuild())
 		if err != nil {
 			logrus.Warnln("Skipping test and deploy due to build error:", err)
 			event.DevLoopFailedInPhase(r.devIteration, constants.Build, err)
 			eventV2.TaskFailed(constants.DevLoop, err)
+			endTrace(instrumentation.TraceEndError(err))
 			return nil
 		}
 		r.changeSet.Redeploy()
 		needsDeploy = deployIntent
+		endTrace()
 	}
 
 	// Trigger retest when there are newly rebuilt artifacts or untested previous artifacts; and it's not explicitly skipped
 	if (len(bRes) > 0 || needsTest) && !r.runCtx.SkipTests() {
+		childCtx, endTrace := instrumentation.StartTrace(ctx, "doDev_needsTest")
 		event.ResetStateOnTest()
 		defer func() {
 			r.changeSet.ResetTest()
@@ -136,39 +150,51 @@ func (r *SkaffoldRunner) doDev(ctx context.Context, out io.Writer, logger *logge
 				bRes = append(bRes, a)
 			}
 		}
-		if err := r.Test(ctx, out, bRes); err != nil {
+		if err := r.Test(childCtx, out, bRes); err != nil {
 			if needsDeploy {
 				logrus.Warnln("Skipping deploy due to test error:", err)
 			}
 			event.DevLoopFailedInPhase(r.devIteration, constants.Test, err)
 			eventV2.TaskFailed(constants.DevLoop, err)
+			endTrace(instrumentation.TraceEndError(err))
 			return nil
 		}
+		endTrace()
 	}
 
 	if needsDeploy {
+		childCtx, endTrace := instrumentation.StartTrace(ctx, "doDev_needsDeploy")
 		event.ResetStateOnDeploy()
 		defer func() {
 			r.changeSet.ResetDeploy()
 			r.intents.ResetDeploy()
 		}()
 
-		forwarderManager.Stop()
+		for _, w := range watchers {
+			logrus.Debugf("stopping watcher %s", w.Name())
+			w.Stop()
+		}
 		if !meterUpdated {
 			instrumentation.AddDevIteration("deploy")
 		}
-		if err := r.Deploy(ctx, out, r.Builds); err != nil {
+		if err := r.Deploy(childCtx, out, r.Builds); err != nil {
 			logrus.Warnln("Skipping deploy due to error:", err)
 			event.DevLoopFailedInPhase(r.devIteration, constants.Deploy, err)
 			eventV2.TaskFailed(constants.DevLoop, err)
+			endTrace(instrumentation.TraceEndError(err))
 			return nil
 		}
-		if err := forwarderManager.Start(ctx, r.runCtx.GetNamespaces()); err != nil {
-			logrus.Warnln("Port forwarding failed:", err)
+		for _, w := range watchers {
+			if err := w.Start(childCtx, r.runCtx.GetNamespaces()); err != nil {
+				logrus.Warnf("\n%s failed: %s", w.Name(), err)
+			}
 		}
+
+		endTrace()
 	}
 	event.DevLoopComplete(r.devIteration)
 	eventV2.TaskSucceeded(constants.DevLoop)
+	endTrace()
 	logger.Unmute()
 	return nil
 }
@@ -177,8 +203,14 @@ func (r *SkaffoldRunner) doDev(ctx context.Context, out io.Writer, logger *logge
 // config until interrupted by the user.
 func (r *SkaffoldRunner) Dev(ctx context.Context, out io.Writer, artifacts []*latestV1.Artifact) error {
 	event.DevLoopInProgress(r.devIteration)
-	eventV2.TaskInProgress(constants.DevLoop)
+	eventV2.InitializeState(r.runCtx)
+	eventV2.TaskInProgress(constants.DevLoop, "")
 	defer func() { r.devIteration++ }()
+	eventV2.LogMetaEvent()
+	ctx, endTrace := instrumentation.StartTrace(ctx, "Dev", map[string]string{
+		"devIteration": strconv.Itoa(r.devIteration),
+	})
+
 	g := getTransposeGraph(artifacts)
 	// Watch artifacts
 	start := time.Now()
@@ -214,6 +246,7 @@ func (r *SkaffoldRunner) Dev(ctx context.Context, out io.Writer, artifacts []*la
 			); err != nil {
 				event.DevLoopFailedWithErrorCode(r.devIteration, proto.StatusCode_DEVINIT_REGISTER_BUILD_DEPS, err)
 				eventV2.TaskFailed(constants.DevLoop, err)
+				endTrace()
 				return fmt.Errorf("watching files for artifact %q: %w", artifact.ImageName, err)
 			}
 		}
@@ -228,6 +261,7 @@ func (r *SkaffoldRunner) Dev(ctx context.Context, out io.Writer, artifacts []*la
 		); err != nil {
 			event.DevLoopFailedWithErrorCode(r.devIteration, proto.StatusCode_DEVINIT_REGISTER_TEST_DEPS, err)
 			eventV2.TaskFailed(constants.DevLoop, err)
+			endTrace()
 			return fmt.Errorf("watching test files: %w", err)
 		}
 	}
@@ -239,6 +273,7 @@ func (r *SkaffoldRunner) Dev(ctx context.Context, out io.Writer, artifacts []*la
 	); err != nil {
 		event.DevLoopFailedWithErrorCode(r.devIteration, proto.StatusCode_DEVINIT_REGISTER_DEPLOY_DEPS, err)
 		eventV2.TaskFailed(constants.DevLoop, err)
+		endTrace()
 		return fmt.Errorf("watching files for deployer: %w", err)
 	}
 
@@ -249,6 +284,7 @@ func (r *SkaffoldRunner) Dev(ctx context.Context, out io.Writer, artifacts []*la
 	); err != nil {
 		event.DevLoopFailedWithErrorCode(r.devIteration, proto.StatusCode_DEVINIT_REGISTER_CONFIG_DEP, err)
 		eventV2.TaskFailed(constants.DevLoop, err)
+		endTrace()
 		return fmt.Errorf("watching skaffold configuration %q: %w", r.runCtx.ConfigurationFile(), err)
 	}
 
@@ -258,6 +294,7 @@ func (r *SkaffoldRunner) Dev(ctx context.Context, out io.Writer, artifacts []*la
 	if err := sync.Init(ctx, artifacts); err != nil {
 		event.DevLoopFailedWithErrorCode(r.devIteration, proto.StatusCode_SYNC_INIT_ERROR, err)
 		eventV2.TaskFailed(constants.DevLoop, err)
+		endTrace()
 		return fmt.Errorf("exiting dev mode because initializing sync state failed: %w", err)
 	}
 
@@ -266,6 +303,7 @@ func (r *SkaffoldRunner) Dev(ctx context.Context, out io.Writer, artifacts []*la
 	if err != nil {
 		event.DevLoopFailedInPhase(r.devIteration, constants.Build, err)
 		eventV2.TaskFailed(constants.DevLoop, err)
+		endTrace()
 		return fmt.Errorf("exiting dev mode because first build failed: %w", err)
 	}
 	// First test
@@ -273,6 +311,7 @@ func (r *SkaffoldRunner) Dev(ctx context.Context, out io.Writer, artifacts []*la
 		if err = r.Test(ctx, out, bRes); err != nil {
 			event.DevLoopFailedInPhase(r.devIteration, constants.Build, err)
 			eventV2.TaskFailed(constants.DevLoop, err)
+			endTrace()
 			return fmt.Errorf("exiting dev mode because test failed after first build: %w", err)
 		}
 	}
@@ -290,6 +329,7 @@ func (r *SkaffoldRunner) Dev(ctx context.Context, out io.Writer, artifacts []*la
 	if err := r.Deploy(ctx, out, r.Builds); err != nil {
 		event.DevLoopFailedInPhase(r.devIteration, constants.Deploy, err)
 		eventV2.TaskFailed(constants.DevLoop, err)
+		endTrace()
 		return fmt.Errorf("exiting dev mode because first deploy failed: %w", err)
 	}
 
@@ -311,9 +351,10 @@ func (r *SkaffoldRunner) Dev(ctx context.Context, out io.Writer, artifacts []*la
 
 	event.DevLoopComplete(r.devIteration)
 	eventV2.TaskSucceeded(constants.DevLoop)
+	endTrace()
 	r.devIteration++
 	return r.listener.WatchForChanges(ctx, out, func() error {
-		return r.doDev(ctx, out, logger, forwarderManager)
+		return r.doDev(ctx, out, logger, forwarderManager, debugContainerManager)
 	})
 }
 
